pub struct VNumber(/* private fields */);Expand description
A JSON number value.
VNumber can represent integers (signed and unsigned) and floating point numbers.
It stores the number in the most appropriate internal format.
Implementations
Sourceimpl VNumber
impl VNumber
Sourcepub fn to_f64_lossy(&self) -> f64
pub fn to_f64_lossy(&self) -> f64
Converts to f64, potentially losing precision.
Sourcepub fn is_float(&self) -> bool
pub fn is_float(&self) -> bool
Returns true if this number was created from a floating point value.
Sourcepub fn is_integer(&self) -> bool
pub fn is_integer(&self) -> bool
Returns true if this number is an integer (signed or unsigned).